@@ -13,21 +13,19 @@ class ZenoOptions:
                             either raw labels or path to labels.
         output_column (str): Column in dataframe with a given
                              model's raw output or path to output
-        data_type (str): Either "raw" or "path".
-        output_type (str): Either "raw" or "path".
-        data_path (str): Path to directory with data, concatenated with
-                         data_column for 'path' data_type.
-        output_path (str): Path to directory with a given model's output, concatenated
-                           with output_column for 'path' data_type
+        data_path (str): Path to directory with data files.
+        label_path (str): Path to directory with label files.
+        output_path (str): Path to directory with a given model's output.
+        distill_columns (map[str, str]): Map from distiller name to distill column.
     """
 
     id_column: str
     data_column: str
     label_column: str
     output_column: str
-    data_type: str
-    output_type: str
+    distill_columns: dict[str, str]
     data_path: str
+    label_path: str
     output_path: str
 
 
@@ -49,6 +47,15 @@ def distill_function(func):
     return _wrapper
 
 
+def transform_function(func):
+    @functools.wraps(func)
+    def _wrapper(*args, **kwargs):
+        return func(*args, **kwargs)
+
+    _wrapper.transform_function = True
+    return _wrapper
+
+
 def metric_function(func):
     @functools.wraps(func)
     def _wrapper(*args, **kwargs):
